package cn.im47.cms.functional;

import cn.im47.cms.Start;
import org.eclipse.jetty.server.Server;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.jdbc.datasource.SimpleDriverDataSource;
import org.springside.modules.test.data.DataFixtures;
import org.springside.modules.test.jetty.JettyFactory;
import org.springside.modules.utils.PropertiesLoader;

import java.net.URL;
import java.sql.Driver;

/**
 * 功能测试基类.
 * <p/>
 * 在整个测试期间启动一次Jetty Server, 并在每个TestCase执行前中重新载入默认数据.
 * <p/>
 * User: baitao.jibt (dreambt@gmail.com)
 * Date: 12-3-20
 * Time: 上午00:12
 */
@Ignore
public class BaseFunctionalTestCase {

    protected static String baseUrl;

    protected static Server jettyServer;

    protected static SimpleDriverDataSource dataSource;

    protected static PropertiesLoader propertiesLoader = new PropertiesLoader("classpath:/application.properties",
            "classpath:/application.functional.properties", "classpath:/application.functional-local.properties");

    private static Logger logger = LoggerFactory.getLogger(BaseFunctionalTestCase.class);

    @BeforeClass
    public static void beforeClass() throws Exception {
        baseUrl = propertiesLoader.getProperty("baseUrl", Start.BASE_URL);

        Boolean isEmbedded = new URL(baseUrl).getHost().equals("localhost");

        if (isEmbedded) {
            startJettyOnce();
        }

        buildDataSourceOnce();
        reloadSampleData();
    }

    /**
     * 启动Jetty服务器, 在整个功能测试期间仅启动一次.
     */
    protected static void startJettyOnce() throws Exception {
        if (jettyServer == null) {
            //设定Spring的profile
            System.setProperty("spring.profiles.active", "functional");

            jettyServer = JettyFactory.createServerInSource(new URL(baseUrl).getPort(), Start.CONTEXT);
            jettyServer.start();

            logger.info("Jetty Server started");
        }
    }

    /**
     * 构造数据源，仅构造一次
     */
    protected static void buildDataSourceOnce() throws ClassNotFoundException {
        if (dataSource == null) {
            dataSource = new SimpleDriverDataSource();
            dataSource.setDriverClass((Class<? extends Driver>) Class.forName(propertiesLoader
                    .getProperty("jdbc.driver")));
            dataSource.setUrl(propertiesLoader.getProperty("jdbc.url"));
            dataSource.setUsername(propertiesLoader.getProperty("jdbc.username"));
            dataSource.setPassword(propertiesLoader.getProperty("jdbc.password"));
        }
    }

    /**
     * 载入测试数据.
     */
    protected static void reloadSampleData() throws Exception {
        DataFixtures.executeScript(dataSource, "/data/import-data.sql");
    }
}